package Wx

import (
	"context"
	"wechat-api/ent/predicate"
	"wechat-api/ent/wx"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetWxListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetWxListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetWxListLogic {
	return &GetWxListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetWxListLogic) GetWxList(req *types.WxListReq) (*types.WxListResp, error) {
	organizationId := l.ctx.Value("organizationId").(uint64)

	var predicates []predicate.Wx
	predicates = append(predicates, wx.OrganizationIDEQ(organizationId))
	if req.Port != nil {
		predicates = append(predicates, wx.PortContains(*req.Port))
	}
	if req.ProcessId != nil {
		predicates = append(predicates, wx.ProcessIDContains(*req.ProcessId))
	}
	if req.Callback != nil {
		predicates = append(predicates, wx.CallbackContains(*req.Callback))
	}
	data, err := l.svcCtx.DB.Wx.Query().Where(predicates...).WithAgent().Page(l.ctx, req.Page, req.PageSize)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp := &types.WxListResp{}
	resp.Msg = errormsg.Success
	resp.Data.Total = data.PageDetails.Total

	for _, v := range data.List {
		var agent types.AgentInfo
		if v.Edges.Agent != nil {
			agent = types.AgentInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.AgentID,
					CreatedAt: pointy.GetPointer(v.Edges.Agent.CreatedAt.UnixMilli()),
					UpdatedAt: pointy.GetPointer(v.Edges.Agent.UpdatedAt.UnixMilli()),
				},
				Name:       &v.Edges.Agent.Name,
				Role:       &v.Edges.Agent.Role,
				Status:     &v.Edges.Agent.Status,
				Background: &v.Edges.Agent.Background,
				Examples:   &v.Edges.Agent.Examples,
			}
		}

		resp.Data.Data = append(resp.Data.Data,
			types.WxInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.ID,
					CreatedAt: pointy.GetPointer(v.CreatedAt.UnixMilli()),
					UpdatedAt: pointy.GetPointer(v.UpdatedAt.UnixMilli()),
				},
				Status:         &v.Status,
				ServerId:       &v.ServerID,
				Port:           &v.Port,
				ProcessId:      &v.ProcessID,
				Callback:       &v.Callback,
				Wxid:           &v.Wxid,
				Account:        &v.Account,
				Nickname:       &v.Nickname,
				Tel:            &v.Tel,
				HeadBig:        &v.HeadBig,
				OrganizationId: &v.OrganizationID,
				AgentId:        &v.AgentID,
				AgentInfo:      &agent,
			})
	}

	return resp, nil
}
